@@ -1,6 +1,6 @@
 /*
 spacenavd - a free software replacement driver for 6dof space-mice.
-Copyright (C) 2007-2022 John Tsiombikas <nuclear@member.fsf.org>
+Copyright (C) 2007-2025 John Tsiombikas <nuclear@mutantstargoat.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -164,7 +164,7 @@ int open_dev_usb(struct device *dev)
 			/* Wireless devices use the same dongle, try to guess which actual
 			 * device this is, and apply the button hack if it's a SpcMouse Pro
 			 */
-			if(dev->num_buttons >= 255) {
+			if(dev->num_buttons > 2) {
 				dev->type = DEV_SMPROW;
 				dev->bnhack = bnhack_smpro;
 				dev->num_buttons = bnhack_smpro(-1);
